Macro "Style Sampler" 
    // This add-in shows you how the various Maptitude colors, area fills,
    // line types and symbol fonts look on your printer or plotter.  
    // Because the final colors produced by a printer or plotter often do not
    // exactly match those on the screen, the best way to see how colors will 
    // print is to print all of them in a form similar to the color swatches
    // you see in paint stores.

    // These printouts also serve as handy reference guides when you are writing
    // GISDK programs and need to look up the number of a color or font symbol.
    //
    // You can print any or all of nine 8 1/2" X 11" pages of style samples:
    //
    // 1. Colors and fills
    // 2. Line styles part 1
    // 3. Line styles part 2
    // 4. Discrete variable theme colors/fills
    // 5. Continuous variable theme colors
    // 6. Continuous variable theme fills
    // 7. Font point size samples (1-35 points)
    // 8. Caliper font/symbol samples Part 1 (12 point)
    // 9. Caliper font/symbol samples Part 2 (12 point)
    //
    // A dialog box allows you to pick any or all of the pages and to view 
    // them on screen or print with or without prompting you to load the page 
    // into the printer or plotter.
    //
    // Installation
    //
    // This program should be compiled and then loaded into Maptitude as an add-in:
    //
    // To compile:
    // 1. Copy this Style Sampler.rsc file into any directory; usually you will want
    //    to keep your add-ins in a separate directory such as "\addins".
    // 2. Choose Tools-Add-Ins and open the GIS Developer's Kit toolbox.
    // 3. Use the "Compile to UI" button (3rd button from the left) to compile the 
    //    resource file into the same directory.  Save it as Style Sampler.dbd.
    //    (This also creates Style Sampler.1 through Style Sampler.6)

    // Set up as add-in:
    // 1. In Maptitude choose Tools-Add-Ins.
    // 2. Click Setup to display the Setup Add-ins dialog box.
    // 3. Click Add to add a new, untitled add-in.
    // 4. Type "Maptitude Style Sampler" in the Description edit box.
    // 5. Type "Style Sampler" (the name of the main macro in the 
    //    resource file) in the Name edit box.
    // 6. Type the full path and name of the Style Sampler.dbd file,
    //     eg., c:\addins\Style Sampler.dbd, in the UI Database edit box.
    // 7. Click OK to save the new add-in.

    // To run the add-in, choose Tools-Add-Ins, highlight "Maptitude Style Sampler",
    // and click OK.
    //

    // INITIALIZE -------------------------------------------------------------------

    // Array with one element for each page that can be chosen by the user.
    // If the element value is set to 1 then the corresponding page 
    // is chosen.
    dim page_choices[9]

    // Names of macros to run for each page.
    page_macros={
        "create colorfills layout",       // page 1
        "create linestyles part 1 layout",
        "create linestyles part 2 layout",
        "create discrete variables layout",
        "continuous variable colors layout",
        "continuous variable fills layout",
        "create font size samples layout",
        "create font samples layout part 1",
        "create font samples layout part 2"}     // page 9

    // Initialize to display to screen; 1=Print, no prompt; 2=Print with prompt,
    // 3=Display only.
    display_choice=3  // display to screen

    // Set some globals for use by each of the page creation macros.
    global colors, fstyles, lstyles, dcolors, dfstyles, ccolors, c_styles, 
    	layname, hppi, black, line_widths,  solidline

    hppi=7200   // Number of hundredths of points per inch; there are 72 
                // points per inch.  Positions on layouts are specified in 
                // hundredths of points, but giving the positions in inches 
                // is easier, so we multiply the inches by hppi.

    // Initialize some style elements for use in the display.
    black=ColorRGB(0,0,0)  // the color black
    line_widths={0,.5, 1, 2, 3, 4, 5}
    solidline=LineStyle({{{1, -1, 0}}})

    // Set layout name to null to force creation of layout if add-in is run
    // again during same session.  See CreateLayout() function below.
    layname=null
    
    // Load the sample styles arrays; these macros are part of Maptitude rather  
    // than the GISDK, but because you are running this add-in within Maptitude  
    // they are accessible.

    // Colors.
    colors=runmacro("G30 setup colors")          

    // Area fill styles.
    fstyles=runmacro("G30 setup fill styles")    

    // Line styles.
    lstyles=runmacro("G30 setup line styles")    

    // Color sets for discrete variable themes. 
    dcolors=runmacro("G30 setup colorsplay")   
  
    // Fill styles for discrete variable themes.
    dfstyles=runmacro("G30 setup fillsplay")       

    // Color pallette parameters for continuous variable themes.
    // The array contains parameters for GeneratePalette().
    ccolors=runmacro("G30 setup palettes")         
                                                        
    // Fill styles for continuous variable themes.
    c_styles=runmacro("G30 setup quantile fillstyles")
    
    // Query user for which pages to display/print.
    get_choices:
    // The dbox returns the user choices values in the two parameters.
    // The variable display_choice is prefixed with "&" so its value can be 
    // changed in the dbox.  Variable page_choices doesn't need the prefix 
    // because it is an array.  The dbox return value is the name of the 
    // button chosen to exit the dbox ("OK" or "Close").

    result=RunDbox("get samples pages", &display_choice, page_choices)
    if result="Close" then goto quit
  
    // If not already done, create a layout using the default printer.
    if layname=null then do
        CreateLayout("printout",{{"Size",100,100}})    
        layname=GetLayout()

        // Draw the layout so it displays properly.
        DrawLayout()

        end
  
    // If user chose printing, then display the printer common (Windows) dialog.
    if display_choice=1 or display_choice=2 then do
        // Initialize printer
        On escape do return() end
        pages=LayoutProperties()
        on escape default
        end

    // Create and display or print the chosen pages.
    for i=1 to page_choices.length do
        if page_choices[i]=1 then do

            // Create the page on the layout by running the macro name 
            // corresponding to the current page specified by loop index i.

            runmacro(page_macros[i])

            // If page prompt chosen then issue the prompt.
            if display_choice=2 then showmessage("Load 8 1/2 X 11 page now.")
    
            // If print chosen then print the layout, otherwise just allow
            // user to view it.      
            if display_choice=1 or display_choice=2 then do

                // If user cancels the printing then quit.
                on escape do        
                    on escape default
                    goto quit
                end
    
                // Print the page.
                PrintLayout(1,1) 

                // View the page, without printing.
                end 
            else do

                // Prompt user with modal message to continue or cancel.
                // "Modal" forces user to enter response in order to continue.
                response=MessageBox("Continue?", {
                    {"Caption", "Style Sampler"},
                    {"Buttons", "OKCancel"},
                    {"Icon", "Question"}})
                if response="Cancel" then goto quit
                end

            // Remove the annotations from the layout.
            annos=GetAnnotations()
            dropannotations(,annos)

        end
    end
  
    // Prompt user again.
    goto get_choices
  
    quit:

    //  Close the layout if it has been created.
    if layname<>null then CloseLayout(layname)
  
endmacro
  
// Choose samples pages------------------------------------------------
Dbox "get samples pages" (display_choice, page_choices) 
    Title: "Choose sample pages to print"

    // Frame to enclose the page checkboxes.
    Frame 1,0,44,18 

    // Checkboxes to choose output pages.
    Checkbox 2,1 Prompt: "1. Colors and fills" 
        Variable: page_choices[1]
    Checkbox 2,3 Prompt: "2. Line styles Part 1" 
        Variable: page_choices[2]
    Checkbox 2,5 Prompt: "3. Line styles Part 2" 
        Variable: page_choices[3]
    Checkbox 2,7 Prompt: "4. Discrete variable theme colors/fills" 
        Variable: page_choices[4]
    Checkbox 2,9 Prompt: "5. Continuous variable theme colors" 
        Variable: page_choices[5]
    Checkbox 2,11 Prompt: "6. Continuous variable theme fills" 
        Variable: page_choices[6]
    Checkbox 2,13 Prompt: "7. Font point size samples (1-35 points)" 
        Variable: page_choices[7]
    Checkbox 2,15 Prompt: "8. Caliper font/symbol samples part 1 (12 point)" 
        Variable: page_choices[8]
    Checkbox 2,17 Prompt: "9. Caliper font/symbol samples part 2 (12 point)" 
        Variable: page_choices[9]

    // Radio List for type of printout.
    Radio List 1,19,37,6 Variable: display_choice 
        Radio Button 2,20 Prompt: "Print chosen pages continuously"
        Radio Button 2,22 Prompt: "Print pages--prompt to load each page"
        Radio Button 2,24 Prompt: "View only (no printout)"

    // Run and Close buttons.
    Button  "Run" 47,2,8,1.5 Default Key: Alt_O do
        if page1=0 and page2=0 and page3=0 and 
  	        page4=0 and page5=0 and page6=0 and page7=0 then do
            showmessage("Please choose at least one page or click Close.")
            goto end_run
        end
        return("Run")
        end_run:
        enditem

    Button "Close" same,5,8,1.5 Cancel do
        return("Close")
        enditem
EndDBox
  
// 1. Create color/fills layout------------------------------------------
macro "create colorfills layout"

    // Page title and footers.
    titleid=AddAnnotation("Layout|"+layname,"Text",{
      	{"Color",black},{"Angle",0},
      	{"Font","Arial|Bold|20"},
    	{"Location",{coord(r2i(2.*hppi),r2i(.7*hppi)),
   	    	coord(r2i(6.5*hppi),r2i(.95*hppi))}},
      	{"Text","1. Maptitude Colors and Fills"}})
  
    // Page parameters.
    content_height=8.2  // height of portion of page reserved for the content
    left_margin=1       // in inches
    top_margin=1.25     // in inches
    row_height=.38      // seperation between rows in inches
    col_width=.73       // separation between columns in inches
    sq_size=.29         // size of sample square in inches
    index_offset=.15    // offset of index number within col from left side
    sq_offset=.25       // offset of sample square within col from left side
    row_offset=0        // inches from top line (excluding top margin)
    col_offset=0        // inches from left side (exluding top margin)

    // Loop through colors array adding index number and samples.
    for i=1 to colors.length do

        // Compute location of index number.
        indexloc={coord(r2i((left_margin*hppi)+(col_offset*hppi)+index_offset*hppi),
  	        r2i((top_margin*hppi)+(row_offset*hppi))),
  	        coord(r2i((left_margin*hppi)+(col_offset*hppi)+index_offset),
  	        r2i((top_margin*hppi)+(row_offset*hppi)+sq_size*hppi))}

        // Add color index numbers.
        indexid=AddAnnotation("Layout|"+layname,"Text",{
  	        {"Color",black},{"Angle",0},
  	        {"Font","Arial|Bold|12"},
  	        {"Location",indexloc},  
  	        {"Text",string(i)}})
  
        // Compute color sample location.
        loc={coord(r2i( (left_margin+col_offset+sq_offset)*hppi ) ,
  	        r2i( (top_margin+row_offset)*hppi )),
          	coord(r2i( (left_margin+col_offset+sq_offset+sq_size)*hppi ),
  	        r2i( (top_margin+row_offset+sq_size)*hppi ))}

        // Add color samples.
        id=AddAnnotation("Layout|"+layname,"Rectangle",{
          	{"Location",loc},
          	{"Line Color",black},
          	{"Line Width",0},
          	{"Line Style",solidline},
            {"Fill Color",colors[i]}
        	})
  
        // If at the end of a column then go to next column.
        row_offset=row_offset+row_height
        if row_offset>content_height then do
            row_offset=0
            col_offset=col_offset+col_width
            end

        end
  
    // Add fills to layout.
    row_offset=0
    col_offset=col_offset+col_width

    // Loop through fill styles array.
    for i=1 to fstyles.length do

        // Compute location of fill style index number.
        indexloc={coord(r2i((left_margin*hppi)+(col_offset*hppi)+index_offset*hppi),
  	        r2i((top_margin*hppi)+(row_offset*hppi))),
  	        coord(r2i((left_margin*hppi)+(col_offset*hppi)+index_offset),
  	        r2i((top_margin*hppi)+(row_offset*hppi)+sq_size*hppi))}

        // Add fill style index numbers.
        indexid=AddAnnotation("Layout|"+layname,"Text",{
  	        {"Color",black},{"Angle",0},
  	        {"Font","Arial|Bold|12"},
  	        {"Location",indexloc},
  	        {"Text",string(i)}})
  
        // Compute fill style location.
        loc={coord(r2i( (left_margin+col_offset+sq_offset)*hppi ) ,
  	        r2i( (top_margin+row_offset)*hppi )),
  	        coord(r2i( (left_margin+col_offset+sq_offset+sq_size)*hppi ),
  	        r2i( (top_margin+row_offset+sq_size)*hppi ))}

        // Add fill style samples.
        id=AddAnnotation("Layout|"+layname,"Rectangle",{
  	        {"Location",loc},
  	        {"Line Color",black},
  	        {"Line Width",0},
  	        {"Line Style",solidline},
            {"Fill Color",black},
  	        {"Fill Style",fstyles[i]}
  	        })
  
        // If at the end of a column then go to next column.
        row_offset=row_offset+row_height
        if row_offset>content_height then do
            row_offset=0
            col_offset=col_offset+col_width
            end

        end

    // Add footer.
    runmacro("add page footer")
endmacro
 
// 2. Create linestyles part 1 layout-------------------------------------------
macro "create linestyles part 1 layout"

    // Page title and subhead.
    titleid=AddAnnotation("Layout|"+layname,"Text",{
      	{"Color",black},{"Angle",0},
      	{"Font","Arial|Bold|20"},
      	{"Location",{coord(r2i(2.*hppi),r2i(.7*hppi)),
  		coord(r2i(6.5*hppi),r2i(.95*hppi))}},
      	{"Text","2. Maptitude Line Styles Part 2 (1-50)"}})

    titleid=AddAnnotation("Layout|"+layname,"Text",{
      	{"Color",black},{"Angle",0},
      	{"Font","Arial|Bold|12"},
      	{"Location",{coord(r2i(1.*hppi),r2i(1.3*hppi)),
  		coord(r2i(2.7*hppi),r2i(1.4*hppi))}},  
      	{"Text","Line width in points"}})
  
    // Page parameters.
    content_height=10.  // height of portion of page reserved for the content
    left_margin=1.25    // in inches
    top_margin=1.4    // in inches
    row_height=.15   // seperation between rows in inches
    col_width=.9      // separation between columns in inches
    sample_width=.8   // width of line sample in inches
  
    row_offset=.05   // inches from top line (excluding top margin)
    col_offset=0     // inches from left side (exluding top margin)
    for i=1 to line_widths.length do
        // Add linestyle line widths.
        indexloc={coord(r2i((left_margin*hppi)+(col_offset*hppi)+.3*hppi),
          	r2i((top_margin*hppi)+(row_offset*hppi))),
          	coord(r2i((left_margin*hppi)+(col_offset*hppi)+.5*hppi),
          	r2i((top_margin*hppi)+(row_offset*hppi)+.1*hppi))}
        indexid=AddAnnotation("Layout|"+layname,"Text",{
      	    {"Color",black},{"Angle",0},
  	        {"Font","Arial|Bold|10"},
          	{"Location",indexloc},  
          	{"Text",string(line_widths[i])}})
        col_offset=col_offset+col_width
        end
  
    // Add line style samples.
    row_offset=row_offset+.2    // inches from top line (excluding top margin)
    for i=1 to 50 do
        // Add linestyle index numbers
        indexloc={ coord( r2i((left_margin-.1)*hppi),
          	r2i((top_margin*hppi)+(row_offset*hppi)) ),
          	coord( r2i( ((left_margin-.1)*hppi) +5),
          	r2i(  ((top_margin*hppi)+(row_offset*hppi))+5 ) ) }  
        indexid=AddAnnotation("Layout|"+layname,"Text",{
          	{"Color",black},{"Angle",0},
          	{"Font","Arial|Bold|8"},
          	{"Location",indexloc}, 
          	{"Text",string(i)}})
  
        // Add linestyles in all line widths.
        col_offset=0     // inches from left side (exluding top margin)
        for j=1 to line_widths.length do
            points={coord(r2i( (left_margin+col_offset)*hppi ) ,
  	            r2i( (top_margin+row_offset)*hppi )),
    	        coord(r2i( (left_margin+col_offset+sample_width)*hppi ),
  	            r2i( (top_margin+row_offset)*hppi ))}
            id=AddAnnotation("Layout|"+layname,"Polyline",{
  	            {"Line Color",colors[14]},
  	            {"Line Width",line_widths[j]},
  	            {"Line Style",lstyles[i]},
                {"Points",points}})
            col_offset=col_offset+col_width
            end

        row_offset=row_offset+row_height
        end

    // Add footer.
    runmacro("add page footer")
endmacro
  
// 3. Create linestyles part 2 layout-------------------------------------------
macro "create linestyles part 2 layout"

    // Page title and subhead.
    titleid=AddAnnotation("Layout|"+layname,"Text",{
      	{"Color",black},{"Angle",0},
      	{"Font","Arial|Bold|20"},
      	{"Location",{coord(r2i(2.*hppi),r2i(.7*hppi)),
      		coord(r2i(6.5*hppi),r2i(.95*hppi))}},  
       	{"Text","3. Maptitude Line Styles Part 2 (51-101)"}})

    titleid=AddAnnotation("Layout|"+layname,"Text",{
      	{"Color",black},{"Angle",0},
      	{"Font","Arial|Bold|12"},
      	{"Location",{coord(r2i(1.*hppi),r2i(1.25*hppi)),
      		coord(r2i(2.7*hppi),r2i(1.35*hppi))}},  
      	{"Text","Line width in points"}})
  
    // Page parameters.
    content_height=10.  // height of portion of page reserved for the content
    left_margin=1.25    // in inches
    top_margin=1.4    // in inches
    row_height=.15   // seperation between rows in inches
    col_width=.9      // separation between columns in inches
    sample_width=.8   // width of line sample in inches
  
    row_offset=.05   // inches from top line (excluding top margin)
    col_offset=0     // inches from left side (exluding top margin)
    for i=1 to line_widths.length do

        // Add linestyle line widths.
        indexloc={coord(r2i((left_margin*hppi)+(col_offset*hppi)+.3*hppi),
          	r2i((top_margin*hppi)+(row_offset*hppi))),
          	coord(r2i((left_margin*hppi)+(col_offset*hppi)+.5*hppi),
          	r2i((top_margin*hppi)+(row_offset*hppi)+.1*hppi))}  
        indexid=AddAnnotation("Layout|"+layname,"Text",{
          	{"Color",black},{"Angle",0},
          	{"Font","Arial|Bold|10"},
          	{"Location",indexloc},  
          	{"Text",string(line_widths[i])}})
        col_offset=col_offset+col_width
        end
  
    // Add line style samples.
    row_offset=row_offset+.2    // inches from top line (excluding top margin)
  
    for i=51 to 101 do

        // Add linestyle index numbers.
        indexloc={ coord( r2i((left_margin-.1)*hppi),
          	r2i((top_margin*hppi)+(row_offset*hppi)) ),
          	coord( r2i(((left_margin-.1)*hppi)+5),
              	r2i(((top_margin*hppi)+(row_offset*hppi)) )+5) }  
                indexid=AddAnnotation("Layout|"+layname,"Text",{
          	{"Color",black},{"Angle",0},
          	{"Font","Arial|Bold|8"},
          	{"Location",indexloc}, 
          	{"Text",string(i)}})
  
        // Add linestyles in all line widths.
        col_offset=0     // inches from left side (exluding top margin)
        for j=1 to line_widths.length do
            points={coord(r2i( (left_margin+col_offset)*hppi ) ,
  	            r2i( (top_margin+row_offset)*hppi )),
    	        coord(r2i( (left_margin+col_offset+sample_width)*hppi ),
  	            r2i( (top_margin+row_offset)*hppi ))}
            id=AddAnnotation("Layout|"+layname,"Polyline",{
              	{"Line Color",colors[14]},
              	{"Line Width",line_widths[j]},
              	{"Line Style",lstyles[i]},
                {"Points",points}})
            col_offset=col_offset+col_width
            end

        row_offset=row_offset+row_height
        end

    // Add footer.
    runmacro("add page footer")
endmacro
  
// 4. Discrete variable themes color and fills---------------------------
macro "create discrete variables layout"

    // Page title and subhead.
    titleid=AddAnnotation("Layout|"+layname,"Text",{
      	{"Color",black},{"Angle",0},
      	{"Font","Arial|Bold|20"},
      	{"Location",{coord(r2i(2.*hppi),r2i(.7*hppi)),
      		coord(r2i(6.5*hppi),r2i(.95*hppi))}},  
      	{"Text","4. Maptitude Discrete Variable Theme Colors and Fills"}})
  
    // Page parameters.
    left_margin=.9    // in inches
    top_margin=1.1  // in inches
    row_height=.39   // seperation between rows in inches
    col_width=.39     // separation between columns in inches
    sq_size=.29       // size of sample square in inches
    row_offset=.2    // inches from top line (excluding top margin)
    col_offset=0     // inches from left side (exluding top margin)

    for i=1 to 10 do
        // Add sample index numbers (index number within set of colors)
        indexloc={coord(r2i((left_margin*hppi)+(col_offset*hppi)+.13*hppi),
          	r2i((top_margin*hppi)+(row_offset*hppi))),
          	coord(r2i((left_margin*hppi)+(col_offset*hppi)+.15*hppi),
          	r2i((top_margin*hppi)+(row_offset*hppi)+.22*hppi))}  
        indexid=AddAnnotation("Layout|"+layname,"Text",{
          	{"Color",black},{"Angle",0},
          	{"Font","Arial|Bold|10"},
          	{"Location",indexloc},  
          	{"Text",string(i)}})
        col_offset=col_offset+col_width
        end
  
        row_offset=row_offset+.2    // inches from top line (excluding top margin)
  
    // Add color sample index numbers for different sets.
    for i=1 to dcolors.length do
        // Add color set index numbers.
        indexloc={ coord( r2i((left_margin-.1)*hppi),
          	r2i((top_margin*hppi)+(row_offset*hppi)) ),
          	coord( r2i((left_margin-.1)*hppi),
          	r2i( (top_margin*hppi)+(row_offset*hppi)+.2*hppi) ) }  
        indexid=AddAnnotation("Layout|"+layname,"Text",{
          	{"Color",black},{"Angle",0},
          	{"Font","Arial|Bold|10"},
          	{"Location",indexloc}, 
          	{"Text",string(i)}})
           col_offset=0     // inches from left side (exluding top margin)
        for j=1 to dcolors[i].length do
            // Add color samples.
            loc={coord(r2i( (left_margin+col_offset)*hppi ) ,
	            r2i( (top_margin+row_offset)*hppi )),
              	coord(r2i( (left_margin+col_offset+sq_size)*hppi ),
                r2i( (top_margin+row_offset+sq_size)*hppi ))}
            id=AddAnnotation("Layout|"+layname,"Rectangle",{
           		{"Location",loc},
          		{"Line Color",black},
          		{"Line Width",0},
          		{"Line Style",solidline},
      	        {"Fill Color",dcolors[i][j]}})
            col_offset=col_offset+col_width
            end
        row_offset=row_offset+row_height
        end

    // Discrete fills.
    row_offset=row_offset-row_height+.3    // inches from top line (excluding top margin)
    col_offset=0     // inches from left side (exluding top margin)
    for i=1 to 16 do
        // Add sample index numbers (index number with set of colors).
        indexloc={coord(r2i((left_margin*hppi)+(col_offset*hppi)+.13*hppi),
  	        r2i((top_margin*hppi)+(row_offset*hppi))),
  	        coord(r2i((left_margin*hppi)+(col_offset*hppi)+.15*hppi),
  	        r2i((top_margin*hppi)+(row_offset*hppi)+.22*hppi))}  
        indexid=AddAnnotation("Layout|"+layname,"Text",{
  	        {"Color",black},{"Angle",0},
          	{"Font","Arial|Bold|10"},
          	{"Location",indexloc},  
          	{"Text",string(i)}})
        col_offset=col_offset+col_width
        end
  
    row_offset=row_offset+.2    // inches from top line (excluding top margin)
  
    // Add fill sample index numbers for different sets.
    for i=1 to dfstyles.length do

        // Add fill set index numbers.
        indexloc={ coord( r2i((left_margin-.1)*hppi),
          	r2i((top_margin*hppi)+(row_offset*hppi)) ),
          	coord( r2i((left_margin-.1)*hppi),
          	r2i( (top_margin*hppi)+(row_offset*hppi)+.2*hppi) ) }  
        indexid=AddAnnotation("Layout|"+layname,"Text",{
          	{"Color",black},{"Angle",0},
          	{"Font","Arial|Bold|10"},
          	{"Location",indexloc}, 
          	{"Text",string(i)}})
  
        col_offset=0     // inches from left side (exluding top margin)
        for j=1 to dfstyles[i].length do
            // Add fill samples.
            loc={coord(r2i( (left_margin+col_offset)*hppi ) ,
    	        r2i( (top_margin+row_offset)*hppi )),
          	    coord(r2i( (left_margin+col_offset+sq_size)*hppi ),
  	            r2i( (top_margin+row_offset+sq_size)*hppi ))}
            id=AddAnnotation("Layout|"+layname,"Rectangle",{
              	{"Location",loc},
              	{"Line Color",black},
              	{"Line Width",0},
              	{"Line Style",solidline},
                {"Fill Color",black},
              	{"Fill Style",dfstyles[i][j]}})

            col_offset=col_offset+col_width
            end
        row_offset=row_offset+row_height
        end

    // Add footer.
    runmacro("add page footer")
endmacro
  
// 5. Continuous variable themes colors ---------------------------
macro "continuous variable colors layout"

    // Page title and subhead.
    titleid=AddAnnotation("Layout|"+layname,"Text",{
  	{"Color",black},{"Angle",0},
  	{"Font","Arial|Bold|20"},
  	{"Location",{coord(r2i(2.*hppi),r2i(.7*hppi)),
  		coord(r2i(6.5*hppi),r2i(.95*hppi))}},  
  	{"Text","5. Maptitude Continuous Variable Theme Colors"}})
  
    // Page parameters.
    left_margin=1.3  // in inches
    top_margin=.8    // in inches
    row_height=.4   // seperation between rows in inches
    col_width=.4     // separation between columns in inches
    sq_size=.25       // size of sample square in inches
    row_offset=.75   // inches from top line (excluding top margin)
    col_offset=0     // inches from left side (exluding top margin)
    cat5_offset=.7   // where to start 8 category group on right side

    for i=1 to 5 do
        // Add sample index numbers (index number with set of colors).
        indexloc={coord(r2i((left_margin*hppi)+(col_offset*hppi)+.13*hppi),
            r2i((top_margin*hppi)+(row_offset*hppi))),
          	coord(r2i((left_margin*hppi)+(col_offset*hppi)+.15*hppi),
          	r2i((top_margin*hppi)+(row_offset*hppi)+.22*hppi))}  
        indexid=AddAnnotation("Layout|"+layname,"Text",{
          	{"Color",black},{"Angle",0},
          	{"Font","Arial|Bold|10"},
          	{"Location",indexloc},  
          	{"Text",string(i)}})
        col_offset=col_offset+col_width
        end
  
    col_offset=col_offset+.7     // inches from left side (exluding top margin)
    for i=1 to 8 do
        // Add sample index numbers (index number with set of colors).
        indexloc={coord(r2i((left_margin*hppi)+(col_offset*hppi)+.13*hppi),
          	r2i((top_margin*hppi)+(row_offset*hppi))),
          	coord(r2i((left_margin*hppi)+(col_offset*hppi)+.15*hppi),
          	r2i((top_margin*hppi)+(row_offset*hppi)+.22*hppi))}  
        indexid=AddAnnotation("Layout|"+layname,"Text",{
          	{"Color",black},{"Angle",0},
          	{"Font","Arial|Bold|10"},
          	{"Location",indexloc},  
          	{"Text",string(i)}})
        col_offset=col_offset+col_width
        end
  
    row_offset=row_offset+.2    // inches from top line (excluding top margin)
  
    // Add color sample index numbers for different sets.
    for i=1 to ccolors.length do
        // Add color set index numbers.
        indexloc={ coord( r2i((left_margin-.1)*hppi),
          	r2i((top_margin*hppi)+(row_offset*hppi)) ),
          	coord( r2i((left_margin-.1)*hppi),
          	r2i( (top_margin*hppi)+(row_offset*hppi)+.2*hppi) ) }  
        indexid=AddAnnotation("Layout|"+layname,"Text",{
          	{"Color",black},{"Angle",0},
          	{"Font","Arial|Bold|10"},
          	{"Location",indexloc}, 
          	{"Text",string(i)}})
  
        // Add continuous colors.
        col_offset=0     // inches from left side (exluding top margin)
        
        // Create continuous color pallette.
        pal = ccolors[i]
        ccolors5=GeneratePalette(colors[pal[1]], colors[pal[2]], 3, pal[3]) 
        for j=1 to 5 do
            // Add color samples.
            loc={coord(r2i( (left_margin+col_offset)*hppi ) ,
    	        r2i( (top_margin+row_offset)*hppi )),
              	coord(r2i( (left_margin+col_offset+sq_size)*hppi ),
  	            r2i( (top_margin+row_offset+sq_size)*hppi ))}
            id=AddAnnotation("Layout|"+layname,"Rectangle",{
           		{"Location",loc},
          		{"Line Color",black},
          		{"Line Width",0},
          		{"Line Style",solidline},
      	        {"Fill Color",ccolors5[j]}})
            col_offset=col_offset+col_width
            end
  
        // Create continuous color pallette - 8 categories.
        pal = ccolors[i]
        ccolors8=GeneratePalette(colors[pal[1]], colors[pal[2]], 6, pal[3]) 
        for j=1 to 8 do
            // Add color samples.
            loc={coord(r2i( (left_margin+col_offset+cat5_offset)*hppi ) ,
    	        r2i( (top_margin+row_offset)*hppi )),
              	coord(r2i( (left_margin+col_offset+cat5_offset+sq_size)*hppi ),
        	    r2i( (top_margin+row_offset+sq_size)*hppi ))}
            id=AddAnnotation("Layout|"+layname,"Rectangle",{
           		{"Location",loc},
          		{"Line Color",black},
          		{"Line Width",0},
          		{"Line Style",solidline},
                {"Fill Color",ccolors8[j]}})
            col_offset=col_offset+col_width
            end
        row_offset=row_offset+row_height
        end

    // Add footer
    runmacro("add page footer")
endmacro
  
// 6. Continuous variable themes fills ---------------------------
macro "continuous variable fills layout"

    // Page title and subhead.
    titleid=AddAnnotation("Layout|"+layname,"Text",{
  	{"Color",black},{"Angle",0},
  	{"Font","Arial|Bold|20"},
  	{"Location",{coord(r2i(2.*hppi),r2i(.7*hppi)),
  		coord(r2i(6.5*hppi),r2i(.95*hppi))}},  
  	{"Text","6. Maptitude Continuous Variable Theme Fills"}})
  
    // Page parameters.
    left_margin=1.    // in inches
    top_margin=1.4   // in inches
    row_height=.4    // seperation between rows in inches
    col_width=.4      // separation between columns in inches
    sq_size=.25       // size of sample square in inches
    row_offset=.35   // inches from top line (excluding top margin)
    col_offset=0     // inches from left side (exluding top margin)

    // Continuous fills.
    row_offset=row_offset+.2    // inches from top line (excluding top margin)
    col_offset=0     // inches from left side (exluding top margin)
    for i=1 to 16 do
        // Add sample index numbers (index number with set of colors).
        indexloc={coord(r2i((left_margin*hppi)+(col_offset*hppi)+.13*hppi),
  	        r2i((top_margin*hppi)+(row_offset*hppi))),
          	coord(r2i((left_margin*hppi)+(col_offset*hppi)+.15*hppi),
          	r2i((top_margin*hppi)+(row_offset*hppi)+.22*hppi))}  
        indexid=AddAnnotation("Layout|"+layname,"Text",{
  	        {"Color",black},{"Angle",0},
          	{"Font","Arial|Bold|10"},
          	{"Location",indexloc},  
          	{"Text",string(i)}})
        col_offset=col_offset+col_width
        end
  
    row_offset=row_offset+.2    // inches from top line (excluding top margin)
  
    // Add fill sample index numbers for different sets.
    for i=1 to dfstyles.length do
        // Add fill set index numbers.
        indexloc={ coord( r2i((left_margin-.1)*hppi),
  	        r2i((top_margin*hppi)+(row_offset*hppi)) ),
          	coord( r2i((left_margin-.1)*hppi),
          	r2i( (top_margin*hppi)+(row_offset*hppi)+.2*hppi) ) }  
        indexid=AddAnnotation("Layout|"+layname,"Text",{
          	{"Color",black},{"Angle",0},
          	{"Font","Arial|Bold|10"},
          	{"Location",indexloc}, 
          	{"Text",string(i)}})
  
        col_offset=0     // inches from left side (exluding top margin)
        for j=1 to c_styles[i].length do
            // Add fill samples.
            loc={coord(r2i( (left_margin+col_offset)*hppi ) ,
    	        r2i( (top_margin+row_offset)*hppi )),
              	coord(r2i( (left_margin+col_offset+sq_size)*hppi ),
                r2i( (top_margin+row_offset+sq_size)*hppi ))}
            id=AddAnnotation("Layout|"+layname,"Rectangle",{
              	{"Location",loc},
              	{"Line Color",black},
              	{"Line Width",0},
              	{"Line Style",solidline},
                {"Fill Color",black},
              	{"Fill Style",c_styles[i][j]}})
            col_offset=col_offset+col_width
            end
        row_offset=row_offset+row_height
        end

    // Add footer.
    runmacro("add page footer")
endmacro
  
// 7. Font size samples------------------------------------------------
macro "create font size samples layout"
    // Page title and subhead.
    titleid=AddAnnotation("Layout|"+layname,"Text",{
  	{"Color",black},{"Angle",0},
  	{"Font","Arial|Bold|20"},
  	{"Location",{coord(r2i(2.*hppi),r2i(.7*hppi)),
  		coord(r2i(6.5*hppi),r2i(.95*hppi))}},  
  	{"Text","7. Maptitude Font Size Samples (1-54 points)"}})
  
    // Page parameters.
    content_height=8.  // height of portion of page reserved for the content
    left_margin=1.4    // in inches
    top_margin=1.8     // in inches
    row_height=.9    // seperation between rows in inches
    col_width=1      // separation between columns in inches
    sq_size=.5        // size of sample square in inches
    index_offset=.0  // offset of index number within col from left side
    sq_offset=.4    // offset of sample square within col from left side
    row_offset=0     // inches from top line (excluding top margin)
    col_offset=0     // inches from left side (exluding top margin)
    for i=1 to 54 do
        // Add font point sizes.
        indexloc={coord(r2i((left_margin*hppi)+(col_offset*hppi)+index_offset*hppi),
  	        r2i((top_margin*hppi)+(row_offset*hppi))),
          	coord(r2i((left_margin*hppi)+(col_offset*hppi)+index_offset),
          	r2i((top_margin*hppi)+(row_offset*hppi)+sq_size*hppi))}  
        indexid=AddAnnotation("Layout|"+layname,"Text",{
          	{"Color",black},{"Angle",0},
          	{"Font","Arial|Bold|12"},
      	    {"Location",indexloc},  
      	    {"Text",string(i)}})
  
        // Add star at different font sizes.
        loc=coord( r2i( (left_margin+col_offset+sq_offset)*hppi ) ,
  	       r2i( (top_margin+row_offset+.15)*hppi ))
        font_spec="Caliper Cartographic|"+trim(string(i))
        fontid=AddAnnotation("Layout|"+layname,"Font Character",{
          	{"Location",loc},
          	{"Index",64},	
          	{"Font",font_spec},  
          	{"Color",colors[5]},{"Angle",0}})
  
        // If at the end of a column then go to next column.
        row_offset=row_offset+row_height
        if row_offset>content_height then do
            row_offset=0
            col_offset=col_offset+col_width
            end

        end

    // Add footer.
    runmacro("add page footer")
endmacro
  
// 8. Caliper font samples part 1-----------------------------------------------
macro "create font samples layout part 1"

    // Page title and column headings.
    titleid=AddAnnotation("Layout|"+layname,"Text",{
      	{"Color",black},{"Angle",0},
      	{"Font","Arial|Bold|20"},
      	{"Location",{coord(r2i(2.*hppi),r2i(.7*hppi)),
  	    	coord(r2i(6.5*hppi),r2i(.95*hppi))}},  
      	{"Text","8. Maptitude Font Samples Part 1"}})
    titleid=AddAnnotation("Layout|"+layname,"Text",{
      	{"Color",black},{"Angle",0},
      	{"Font","Arial|Bold|12"},
      	{"Location",{coord(r2i(1.*hppi),r2i(1.35*hppi)),
      		coord(r2i(2.6*hppi),r2i(1.6*hppi))}},  
      	{"Text","Caliper Cartographic"}})
    titleid=AddAnnotation("Layout|"+layname,"Text",{
      	{"Color",black},{"Angle",0},
      	{"Font","Arial|Bold|12"},
      	{"Location",{coord(r2i(2.6*hppi),r2i(1.35*hppi)),
      		coord(r2i(4.2*hppi),r2i(1.6*hppi))}},  
      	{"Text","Caliper Miscellaneous"}})
    titleid=AddAnnotation("Layout|"+layname,"Text",{
      	{"Color",black},{"Angle",0},
      	{"Font","Arial|Bold|12"},
      	{"Location",{coord(r2i(4.1*hppi),r2i(1.35*hppi)),
      		coord(r2i(6.1*hppi),r2i(1.6*hppi))}},  
      	{"Text","Caliper Transportation"}})
    titleid=AddAnnotation("Layout|"+layname,"Text",{
      	{"Color",black},{"Angle",0},
      	{"Font","Arial|Bold|12"},
      	{"Location",{coord(r2i(5.8*hppi),r2i(1.35*hppi)),
      		coord(r2i(7.6*hppi),r2i(1.6*hppi))}},  
      	{"Text","Caliper Scales/Arrows"}})
  
    // Page parameters.
    content_height=7.6 // height of portion of page reserved for the content
    left_margin=1.2    // in inches
    top_margin=1.7     // in inches
    row_height=.235     // seperation between rows in inches
    col_width=.55      // separation between columns in inches
  
    row_offset=.0     // inches from top line (excluding top margin)
    col_offset=0     // inches from left side (exluding top margin)
    for i=33 to 126 do
        // Add font index numbers - Caliper Cartographic.
        indexloc={coord(r2i((left_margin*hppi)+(col_offset*hppi)),
  	        r2i((top_margin*hppi)+(row_offset*hppi))),
          	coord(r2i(((left_margin*hppi)+(col_offset*hppi)))+5,
          	r2i(( (top_margin+row_offset)*hppi ))+5 )}  
        indexid=AddAnnotation("Layout|"+layname,"Text",{
  	        {"Color",black},{"Angle",0},
          	{"Font","Arial|Bold|10"},
          	{"Location",indexloc},  
          	{"Text",string(i)}})
  
        // Add font index numbers - Caliper Miscellaneous.
        indexloc={coord(r2i((left_margin*hppi)+(col_offset*hppi)+(col_width*3*hppi)),
          	r2i((top_margin*hppi)+(row_offset*hppi))),
          	coord(r2i(((left_margin*hppi)+(col_offset*hppi)+(col_width*3*hppi))+5),
          	r2i( ((top_margin+row_offset)*hppi)+5 ) )}  
        indexid=AddAnnotation("Layout|"+layname,"Text",{
          	{"Color",black},{"Angle",0},
          	{"Font","Arial|Bold|10"},
          	{"Location",indexloc},  
          	{"Text",string(i)}})
  
        // Add font index numbers - Caliper Transportation.
        indexloc={coord(r2i((left_margin*hppi)+(col_offset*hppi)+(col_width*6*hppi)),
          	r2i((top_margin*hppi)+(row_offset*hppi))),
          	coord(r2i(((left_margin*hppi)+(col_offset*hppi)+(col_width*6*hppi))+5),
          	r2i( ((top_margin+row_offset)*hppi ))+5 )}  
        indexid=AddAnnotation("Layout|"+layname,"Text",{
            {"Color",black},{"Angle",0},
          	{"Font","Arial|Bold|10"},
          	{"Location",indexloc},  
          	{"Text",string(i)}})
  
        // Add font index numbers - Caliper Scale/Arrows.
        indexloc={coord(r2i((left_margin*hppi)+(col_offset*hppi)+(col_width*9*hppi)),
          	r2i((top_margin*hppi)+(row_offset*hppi))),
          	coord(r2i(((left_margin*hppi)+(col_offset*hppi)+(col_width*9*hppi))+5),
          	r2i( ((top_margin+row_offset)*hppi ))+5 )}  
        indexid=AddAnnotation("Layout|"+layname,"Text",{
          	{"Color",black},{"Angle",0},
          	{"Font","Arial|Bold|10"},
          	{"Location",indexloc},  
          	{"Text",string(i)}})
  
        // Add font samples - Caliper Cartographic.
        loc=coord( r2i( (left_margin+col_offset+.25)*hppi ) ,
  	        r2i( (top_margin+row_offset)*hppi ) )
        fontid=AddAnnotation("Layout|"+layname,"Font Character",{
  	        {"Location",loc},
          	{"Index",i},	
          	{"Font","Caliper Cartographic|12"},  
          	{"Color",colors[5]},{"Angle",0}})
  
        // Add font samples - Caliper Miscellaneous.
        loc=coord( r2i( (left_margin+col_offset+(col_width*3)+.25)*hppi ) ,
  	       r2i( (top_margin+row_offset)*hppi ) )
        fontid=AddAnnotation("Layout|"+layname,"Font Character",{
          	{"Location",loc},
          	{"Index",i},	
          	{"Font","Caliper Miscellaneous|12"},  
          	{"Color",colors[5]},{"Angle",0}})
  
        // Add font samples - Caliper Transportation.
        loc=coord( r2i( (left_margin+col_offset+(col_width*6)+.25)*hppi ) ,
  	        r2i( (top_margin+row_offset)*hppi ) )
        fontid=AddAnnotation("Layout|"+layname,"Font Character",{
          	{"Location",loc},
          	{"Index",i},	
          	{"Font","Caliper Transportation|12"},  
          	{"Color",colors[5]},{"Angle",0}})
  
        // Add font samples - Caliper Scales/Arrows.
        // Use larger font size for scales (33-61).
        if i>=33 and i<=61 then do
            loc=coord( r2i( (left_margin+col_offset+(col_width*9)+.3)*hppi ) ,
  	            r2i( (top_margin+row_offset)*hppi ) )
            fontid=AddAnnotation("Layout|"+layname,"Font Character",{
              	{"Location",loc},
              	{"Index",i},	
              	{"Font","Caliper Scales/Arrows|30"},  
              	{"Color",colors[5]},{"Angle",0}})
            end 
        else do
            loc=coord( r2i( (left_margin+col_offset+(col_width*9)+.25)*hppi ) ,
  	            r2i( (top_margin+row_offset)*hppi ) )
            fontid=AddAnnotation("Layout|"+layname,"Font Character",{
      	        {"Location",loc},
              	{"Index",i},	
              	{"Font","Caliper Scales/Arrows|12"},  
              	{"Color",colors[5]},{"Angle",0}})
            end
  
        // If at the end of a column then go to next column.
        row_offset=row_offset+row_height
        if row_offset>content_height then do
            row_offset=0
            col_offset=col_offset+col_width
            end
        end

    // Add page footer.
    runmacro("add page footer")
endmacro
  
// 9. Caliper font samples part 2-----------------------------------------------
macro "create font samples layout part 2"

    // Page title and column headings.
    titleid=AddAnnotation("Layout|"+layname,"Text",{
      	{"Color",black},{"Angle",0},
      	{"Font","Arial|Bold|20"},
      	{"Location",{coord(r2i(2.*hppi),r2i(.8*hppi)),
  	    	coord(r2i(6.5*hppi),r2i(.95*hppi))}},  
      	{"Text","9. Maptitude Font Samples Part 2"}})
    titleid=AddAnnotation("Layout|"+layname,"Text",{
      	{"Color",black},{"Angle",0},
      	{"Font","Arial|Bold|12"},
      	{"Location",{coord(r2i(1.*hppi),r2i(1.35*hppi)),
      		coord(r2i(2.6*hppi),r2i(1.6*hppi))}},  
      	{"Text","State Shields"}})
    titleid=AddAnnotation("Layout|"+layname,"Text",{
      	{"Color",black},{"Angle",0},
      	{"Font","Arial|Bold|12"},
      	{"Location",{coord(r2i(2.6*hppi),r2i(1.35*hppi)),
      		coord(r2i(4.2*hppi),r2i(1.6*hppi))}},  
      	{"Text","Internaltional Shields"}})
  
    // Page parameters.
    content_height=7.6 // height of portion of page reserved for the content
    left_margin=1.2    // in inches
    top_margin=1.7     // in inches
    row_height=.235     // seperation between rows in inches
    col_width=.55      // separation between columns in inches
  
    row_offset=.0     // inches from top line (excluding top margin)
    col_offset=0     // inches from left side (exluding top margin)
    for i=33 to 126 do
        // Add font index numbers - Caliper State Shields.
        indexloc={coord(r2i((left_margin*hppi)+(col_offset*hppi)),
  	        r2i((top_margin*hppi)+(row_offset*hppi))),
          	coord(r2i(((left_margin*hppi)+(col_offset*hppi)))+5,
          	r2i(( (top_margin+row_offset)*hppi ))+5 )}  
        indexid=AddAnnotation("Layout|"+layname,"Text",{
  	        {"Color",black},{"Angle",0},
          	{"Font","Arial|Bold|10"},
          	{"Location",indexloc},  
          	{"Text",string(i)}})
  
        // Add font index numbers - Caliper International Shields.
        indexloc={coord(r2i((left_margin*hppi)+(col_offset*hppi)+(col_width*3*hppi)),
          	r2i((top_margin*hppi)+(row_offset*hppi))),
          	coord(r2i(((left_margin*hppi)+(col_offset*hppi)+(col_width*3*hppi))+5),
          	r2i( ((top_margin+row_offset)*hppi)+5 ) )}  
        indexid=AddAnnotation("Layout|"+layname,"Text",{
          	{"Color",black},{"Angle",0},
          	{"Font","Arial|Bold|10"},
          	{"Location",indexloc},  
          	{"Text",string(i)}})
  
  
        // Add font samples - Caliper State Shields.
        loc=coord( r2i( (left_margin+col_offset+.25)*hppi ) ,
  	        r2i( (top_margin+row_offset)*hppi ) )
        fontid=AddAnnotation("Layout|"+layname,"Font Character",{
  	        {"Location",loc},
          	{"Index",i},	
          	{"Font","Caliper State Shields|12"},  
          	{"Color",colors[5]},{"Angle",0}})
  
        // Add font samples - Caliper International Shields.
        loc=coord( r2i( (left_margin+col_offset+(col_width*3)+.25)*hppi ) ,
  	       r2i( (top_margin+row_offset)*hppi ) )
        fontid=AddAnnotation("Layout|"+layname,"Font Character",{
          	{"Location",loc},
          	{"Index",i},	
          	{"Font","Caliper International Shields|12"},  
          	{"Color",colors[5]},{"Angle",0}})
  
        // If at the end of a column then go to next column.
        row_offset=row_offset+row_height
        if row_offset>content_height then do
            row_offset=0
            col_offset=col_offset+col_width
            end

        end

    // Add page footer.
    runmacro("add page footer")
endmacro

// Add page footer--------------------------------------------------------
macro "add page footer"
    footer="Maptitude Style Sampler, Caliper Corporation, 1172 Beacon St., Newton, MA  "
    footer=footer+"02461 617-527-4700 www.caliper.com"
    titleid=AddAnnotation("Layout|"+layname,"Text",{
  	{"Color",black},{"Angle",0},
  	{"Font","Arial|Bold|Italic|10"},
  	{"Location",{coord(r2i(.5*hppi),r2i(10.1*hppi)),
  		coord(r2i(8*hppi),r2i(10.5*hppi))}},  
  	{"Text",footer}})
endmacro
  
